@@ -417,20 +417,19 @@ class activateSimulation:
         }
 
         response = requests.request("GET", url, headers=headers, data=payload)
-        getCode = response.status_code
+        #print(response.text)
+        if(response.status_code == 401):
+            print("ERROR: 401 - check token expiration")
+            return("ERROR: 401 - check token expiration")
 
-        if getCode == 401:
-            return("Unauthorized")
-        if getCode == 200:
+        if(response.status_code == 200):
             #update if sim is complete or not complete
             parseResponse = json.loads(response.text)
+            #print(parseResponse)
             self.nodeCount = parseResponse["requestedNodeCount"]
             self.hasStarted = parseResponse["hasStarted"]
             self.isComplete = parseResponse["isComplete"]
-        else:
-            print("Error: " + str(getCode))
-            return(getCode)
-
+            
     def getProgress(self):
         url = "https://lexsetapi.azurewebsites.net/api/simulations/getstatus?id=" + str(self.simID)
 
@@ -510,47 +509,21 @@ def activeSimulationNodes(userID, token):
 
     response = requests.request("GET", url, headers=headers, data=payload)
 
-    
+    #update if sim is complete or not complete
     parseResponse = json.loads(response.text)
-    getCode = response.status_code
-    if getCode == 401:
-        return("Unauthorized")
-    if getCode == 200:
-        #update if sim is complete or not complete
-        nodes = 0
-        y = parseResponse
+    nodes = 0
 
-        for item in range(len(y)):
-        
-            if (y[item]['hasStarted']== True) :
-                nodes = nodes + int(y[item]['requestedNodeCount'])
+    y = parseResponse
 
-        return nodes
-    else:
-        print("Error: " + str(getCode))
-        return(getCode)
-
-
-#http request to get compute resources endpoint
-def getComputeResources(id,userToken):
-    url = "https://seahaven.lexset.ai/api/accountusage/GetActiveComputeNodeCount?userid=" + str(id)
-
-    payload={}
-    headers = {
-    'Authorization': 'Bearer ' + userToken
-    }
-
-    response = requests.request("GET", url, headers=headers, data=payload)
-    getCode = response.status_code
-    if getCode == 401:
-        return("Unauthorized")
-    if getCode == 200:
-        parseResponse = json.loads(response.text)
-        return(parseResponse)
-    else:
-        print("Error: " + str(getCode))
-        return(getCode)
+    for item in range(len(y)):
     
+        if (y[item]['hasStarted']== True) :
+            nodes = nodes + int(y[item]['requestedNodeCount'])
+
+    #print(parseResponse)
+    return nodes
+    #self.isComplete = parseResponse["isComplete"]
+
 # Print iterations progress
 def printProgressBar (iteration, total, prefix = '', suffix = '', decimals = 1, length = 100, fill = '█', printEnd = "\n"):
     """
